// prototype of a Leonardo Clock
// following hand drawings by Giacomo Rupil and with the help of Alceo Solari
// code (including mistakes) by Carlo Fonda (ICTP Scientific Fablab, Trieste, Italy), Alberto Tonelli and Stefano Solari
// website: http://scifablab.ictp.it
// e-mail: cfonda@ictp.it
// version 2.1 - Thu, Sep 2, 2021 ***** new improved version for easier assembling (no glue required for final assembling, some parts are pre-glued together, some gears are now coupled with axes using squared blocks *****

// 
// NOTE: Starting from version 2.1 the 200% scaling isn't needed anymore, the model already has the correct size for lasercutting
// NOTE: plywood thikness: 10mm
// NOTE: axes are made of wooden (or metal) round bars with 8mm diameter
//
// the MODULE of all gears is: 1.592
//
// Building material: thickness of plywood panels for the lasercut version, value is: 10mm /standard plywood panels available at DIY shops like Brico/Leroy-Merlain). Using 8mm diam. wooden axes and 608 bearings.
// BASED on code from the previous "Leonardo Clock" version.
// 
// List fo DXF files (and number of copies that are needed):
/*
BASE_A.dxf
BASE_B.dxf
BOCCOLA_x3.dxf      (3 copies)
CARICA_1.dxf
CARICA_2.dxf
CARICA_3_x6.dxf
GEAR_Z10.dxf
GEAR_Z20.dxf
GEAR_Z40.dxf
NOTTOLINO_x4.dxf    (4 copies)
ORIZZ_1_x2.dxf      (2 copies)
ORIZZ_2A.dxf
ORIZZ_2B.dxf
PALETTA_1.dxf
PALETTA_2_x4.dxf    (2 copies)
PALETTA_3.dxf
PALETTA_4_x10.dxf    (10 copies)
PLINTO_1A.dxf
PLINTO_1B.dxf
PLINTO_2A.dxf
PLINTO_2B.dxf
PLINTO_3A.dxf
PLINTO_3B.dxf
PLINTO_4A.dxf
PLINTO_4B.dxf
RUOTA_LEONARDO_1.dxf
RUOTA_LEONARDO_2.dxf
SECONDI.dxf
SOSTEGNO_QUADRO.dxf
SPESSORE_1_x3.dxf   (3 copies)
*/

// List of axes lenght (diameter = 8mm):
/*
TO CHECK!!!
165mm lower axe
160mm  middle axe
60mm higher axe
*/


spessore=10.0; //spessore delle lastre per il lasercutter, in mm
raggioasse=4.0; // raggio degli assi in legno, in mm
raggioforo=11.0; // raggio del foro passaggio asse - per cuscinetti a sfere 608 usare 11 (= 22 mm diametro)
// carico le librerie per gli ingranaggi:
// PS: la libreria va scaricata da questo URL: https://github.com/revarbat/BOSL
// e va correttamente installata. Documentazione: https://github.com/revarbat/BOSL/wiki
include <BOSL/constants.scad>
use <BOSL/involute_gears.scad>


denti=15; // numero di pioli della ruota dello scappamento di leonardo
piolo=14.0; // lunghezza del piolo
raggiopiolo=3.6; // raggio del piolo
distanza=3*spessore; // distanza interna fra le due ruote dello scappamento
raggio=150.0; // raggio della ruota dello scappamento


//$t=0.0;
// rotazione per effetto di animazione

alpha= 0.8; // trasparenza del telaio (parti in grigio)


// complesso della paletta ("ancora" rotante dello scappamento di Leonardo)

color("red") translate([spessore/2 + distanza/2,0,150+raggioasse]) rotate([0,0,sin($t*360*4*15)*20-90]) union() {

// asse verticale
    translate([0,0,40]) cylinder(h=100,r=raggioasse,center=true,$fn=32); // asse verticale
	translate([0,0,-20]) cylinder(h=12,r2=raggioasse, r1=0,center=true,$fn=32); // estremità conica
    
// PALETTA_1
//!projection()
	paletta($fn=64);  // paletta (o àncora)
	
// PALETTA_2 (x4 pezzi)
//!projection()
    union() {
        difference() {
        cylinder(h=spessore*3,r=10,center=true,$fn=32);
        cylinder(h=spessore*3+2,r=raggioasse*0.98,center=true,$fn=32);
        }   
        translate([0,0,85-spessore/2]) difference() {
        cylinder(h=spessore*2,r=10,center=true,$fn=32);
        cylinder(h=spessore*2+2,r=raggioasse*0.98,center=true,$fn=32);
        }
    }
    
// PALETTA_3
//!projection()  
    translate([0,0,85+spessore]) union() {
        cylinder(h=spessore,r=10,center=true,$fn=32);
        
        cube([300,spessore,spessore],center=true); // barra bilancere
    }

// PALETTA_4 (x8 pezzi)
//!projection() rotate([0,90,0]) 
	translate([100,0,95]) rotate([0,90,0]) difference() {
        cylinder(r=8*raggioasse, h=4*spessore, center=true, $fn=8);
        cube([spessore*1.01,spessore*1.01,10*spessore],center=true);
        }  // contrappeso
	translate([-100,0,95]) rotate([0,90,0]) difference() {
        cylinder(r=8*raggioasse, h=4*spessore, center=true, $fn=8);
        cube([spessore*1.01,spessore*1.01,10*spessore],center=true);
        }  // contrappeso
}

// fine del complesso della paletta

// ruote di Leonardo

rotate([$t*360*4+38,0,0]){  // rotazione per effetto di animazione

// RUOTA_LEONARDO_1
//!projection() rotate([0,-90,0])
	difference() {
	  rotate([0,90,0]) leonardogear(radius=raggio,thickness=spessore,pins=denti,pinradius=raggiopiolo,pinlenght=piolo,pinoffset=0,$fn=64); // prima ruota dentata scappamento
	  translate([-40,0,0]) rotate([0,90,0]) cylinder(h=150,r=raggioforo*0.98, $fn=4); // foro centrale (quadrato)
}

// boccola quadrata
// BOCCOLA  (in totale ne servono 3)
//!projection() rotate([0,-90,0])
color("yellow") translate([-1,0,0]) difference() {
    rotate([0,90,0]) cylinder(h=spessore,r=raggioforo, center=true, $fn=4);
    rotate([0,90,0]) cylinder(h=20,r=raggioasse*0.98, center=true, $fn=32); //foro (stretto)
}
	
// SPESSORE_1 (in totale ne servono 3)
//!projection() rotate([0,-90,0])
	difference() {
    //translate([distanza/2+spessore/2,0,0]) rotate([0,90,0]) cylinder(h=spessore*3,r=28,center=true);
        translate([distanza/2+spessore/2,0,0]) rotate([0,90,0]) rotate([0,0,360/(denti)+0*(180/denti)]) cylinder(h=spessore*3,r=raggioasse+4*spessore,center=true, $fn=5);
		translate([-40,0,0]) rotate([0,90,0]) cylinder(h=150,r=raggioasse, $fn=32); // foro centrale
}

// RUOTA_LEONARDO_2
//!projection() rotate([0,-90,0])
	difference() {
    translate([distanza+spessore,0,0]) rotate([0,90,0]) rotate([0,0,-180/denti]) leonardogear(radius=raggio,thickness= spessore,pins=denti,pinradius=raggiopiolo,pinlenght=piolo,pinoffset=1,$fn=64); // seconda ruota dentata scappamento
		
		translate([-40,0,0]) rotate([0,90,0]) cylinder(h=150,r=raggioforo*0.98, $fn=4); // foro centrale (quadrato)
}

// boccola quadrata
// BOCCOLA  (in totale ne servono 3)
//!projection() rotate([0,-90,0])
color("yellow") translate([41,0,0]) difference() {
    rotate([0,90,0]) cylinder(h=spessore,r=raggioforo, center=true, $fn=4);
    rotate([0,90,0]) cylinder(h=20,r=raggioasse*0.98, center=true, $fn=32); //foro (stretto)
}

// asse di rotazione
translate([-30,0,0])	rotate([0,90,0]) cylinder(h=140,r=raggioasse, $fn=32);
}

// fine delle ruote di Leonardo

// ingranaggio principale Z=10
// GEAR_Z10
//!projection() rotate([0,-90,0])
difference() {
	color("blue") translate([80,0,0]) rotate([$t*360,0,0]) rotate([0,90,0]) gear(mm_per_tooth=10, number_of_teeth=10, thickness=spessore, hole_diameter=raggioasse);
    translate([20,0,0]) rotate([0,90,0]) cylinder(h=80,r=raggioasse*0.98, $fn=32);  // foro asse (stretto)
}



// ingranaggio per la ruota dei secondi Z=20
// GEAR_Z20
//!projection() rotate([0,-90,0])
color("green") difference() {
	translate([80,0,48]) rotate([-$t*360*2,0,0]) rotate([0,90,0]) gear(mm_per_tooth=10, number_of_teeth=20, thickness=spessore, hole_diameter=raggioasse*2);
	translate([50,0,48])	rotate([0,90,0]) cylinder(h=80,r=raggioasse*0.98, $fn=32);  // foro asse (stretto)
}
// suo asse di rotazione
translate([50,0,48])	rotate([0,90,0]) cylinder(h=80,r=raggioasse, $fn=32);

// lancetta dei secondi
// SECONDI
//!projection() rotate([0,-90,0])
translate([112,0,48]) rotate([-$t*360*2,0,0]) rotate([0,90,0]) {
	difference() {
	union() {
		cylinder(h=spessore,r=20, $fn=32);  // ruota tonda
	  translate([0,-3,0]) color("red") cube([60,6,spessore]);  // ago dei secondi
	}
	cylinder(h=spessore,r=raggioasse*0.98, $fn=32);  // foro asse (stretto)
}
}

// ingranaggio per la ruota di carica a cricco Z=40
// GEAR_Z40
//!projection() rotate([0,-90,0])
difference() {
translate([80,0,-80]) rotate([-$t*360,0,0]) rotate([0,90,0]) gear(mm_per_tooth=10, number_of_teeth=40, thickness=spessore, hole_diameter=raggioasse*2);
translate([50,0,-80])	rotate([0,90,0]) cylinder(h=160,r=raggioforo*0.98, $fn=4); // foro asse (quadrato)
}

// boccola quadrata
// BOCCOLA  (in totale ne servono 3)
//!projection() rotate([0,-90,0])
color("yellow") translate([80,0,-80]) difference() {
    rotate([0,90,0]) cylinder(h=spessore,r=raggioforo, center=true, $fn=4);
    rotate([0,90,0]) cylinder(h=20,r=raggioasse*0.98, center=true, $fn=32); //foro (stretto)
}

// suo asse di rotazione
translate([50,0,-80])	rotate([0,90,0]) cylinder(h=160,r=raggioasse, $fn=32);


// ruota di carica a cricco per pesi
 translate([112,0,-80]) rotate([-$t*360,0,0]) rotate([0,90,0]) {
// CARICA_1
//!projection() 
	color("green") difference() {
		cylinder(h=spessore,r=60, $fn=32); // base cilindrica liscia
		cylinder(h=160,r=raggioasse*0.98, $fn=32, center=true); // foro asse (stretto)
        // e i 4 fori per i nottolini
        for(i=[0:45:315]) rotate([0,0,i]) translate([-52,0,spessore*3/2]) cylinder(r=0.25, h=160, center=true); // 8 fori ogni 45°
	}
// CARICA_2
//!projection()
	color("pink") translate([0,0,spessore*1.5]) rotate([0,0,3]) difference() {
		gear(mm_per_tooth=12, number_of_teeth=20, thickness=spessore, hole_diameter=raggioasse*2.0);
	  cylinder(h=160,r=raggioasse*1.05, $fn=32, center=true); // foro asse allargato per scorrimento
	}
// CARICA_3  (ne servono 6 pezzi)
//!projection() 
	color("pink") translate([0,0,spessore*2]) difference() {
		cylinder(h=60,r=24, $fn=32); // rocchetto avvolgitore per cavo di carica con peso
		cylinder(h=160,r=raggioasse*1.05, $fn=32, center=true); // foro asse allargato per scorrimento
        
	}
    
    if(true) { // nottolini
    color("lightgreen") translate([-52,0,spessore*3/2]) rotate([0,0,180-67]) nottolino(notlung=20,notforo=0.55,notthick=spessore); // nottolino a Nord
    
    color("lightgreen") translate([0,52,spessore*3/2]) rotate([0,0,27]) nottolino(notlung=20,notforo=0.55,notthick=spessore); // nottolino ad Est
    
    color("lightgreen") translate([52,0,spessore*3/2]) rotate([0,0,-67]) nottolino(notlung=20,notforo=0.55,notthick=spessore); // nottolino a Sud
    
    color("lightgreen") translate([0,-52,spessore*3/2]) rotate([0,0,180+27]) nottolino(notlung=20,notforo=0.55,notthick=spessore); // nottolino ad Ovest
    } 
}

// nottolino (per il taglio laser)
// NOTTOLINO (x4)
//!projection() nottolino(notlung=20,notforo=0.55,notthick=spessore);




// plinto verticale posteriore (2 strati differenti)
color("gray", alpha) {
// PLINTO_1A
//!projection() rotate([0,-90,0])
	difference() {
    translate([-spessore*1.5,0,70]) cube([spessore,40,500],center=true); // plinto verticale 1 (posteriore)
		translate([-40,0,0])	rotate([0,90,0]) cylinder(h=200,r=raggioforo, $fn=32); // foro cuscinetto
		translate([distanza/2 - 30,0,130]) cube([spessore,240,spessore],center=true);  // scanalatura per il tramezzo posteriore
		translate([40,0,210]) cube([144,20,20],center=true);  // foro per trave orizzontale in alto
		translate([8,0,302]) cube([80,20,20],center=true);  // foro per trave di sostegno filo elastico
	}	
// PLINTO_1B
//!projection() rotate([0,-90,0])
	difference() {
    translate([-spessore*2.5,0,70]) cube([spessore,40,500],center=true); // plinto verticale 1 (posteriore)
		translate([-40,0,0])	rotate([0,90,0]) cylinder(h=200,r=raggioasse*1.2, $fn=32); // foro asse (largo)
        #translate([-30,0,210]) rotate([0,90,0]) cylinder(r=1,h=40,center=true); // foro per vite
		#translate([-30,0,302]) rotate([0,90,0]) cylinder(r=1,h=40,center=true); // foro per vite
	}
}
	
	// sostegno del filo elastico
	color("gray", alpha) {
// ORIZZ_1 (servono 2 pezzi)
//!projection()
translate([13,0,302]) cube([70,20,20],center=true); // trave a sbalzo in alto
    }

// trave orizzontale in alto
    
// ORIZZ_2B (strato superiore)
//!projection()
	color("gray", 1)  translate([40,0,215]) difference() {
	  union() { translate([5,0,0]) cube([130,20,spessore],center=true);
			translate([-20,0,0]) cube([60,40,spessore],center=true);
            translate([40,0,0]) cube([20,40,spessore],center=true);
		}
	  translate([-20,0,0]) cylinder(h=20, r=raggioforo, center=true, $fn=32); // foro per cuscinetto
      #translate([20,0,0]) cylinder(r=1,h=40,center=true); // fori per viti
      #translate([60,0,0]) cylinder(r=1,h=40,center=true);
}
// ORIZZ_2A (strato inferiore)
//!projection()
	color("gray", alpha)  translate([40,0,205]) difference() {
	  union() { translate([5,0,0]) cube([130,20,spessore],center=true);
			translate([-20,0,0]) cube([60,40,spessore],center=true);
            translate([40,0,0]) cube([20,40,spessore],center=true);
		}
	  translate([-20,0,0]) cylinder(h=20, r=raggioasse*1.2, center=true, $fn=32); // foro largo per passaggio asse
      #translate([20,0,0]) cylinder(r=1,h=40,center=true); // fori per viti
      #translate([60,0,0]) cylinder(r=1,h=40,center=true);
}



// struttura quadrata di sostegno della paletta (ancora rotante)
// SOSTEGNO_QUADRO
//!projection()
color("cyan") {
translate([distanza/2 + 40 + spessore/2,0,130]) difference() {
    cube([spessore*2,240,spessore],center=true);
    translate([10,0,0]) cube([spessore*2,40,spessore*2],center=true);
    }  // tramezzo anteriore
translate([distanza/2 - 30 - spessore/2,0,130]) difference() {
    cube([spessore*2,240,spessore],center=true);
    translate([-10,0,0]) cube([spessore*2,40,spessore*2],center=true);
    }  // tramezzo posteriore
// tramezzo centrale
  translate([spessore/2 + distanza/2,0,130]) union() {
	  difference() {
	    cube([12,240,spessore],center=true);
		  translate([0,0,4]) cylinder(h=spessore,r2=raggioasse, r1=0,center=true,$fn=32); // forato
	  }
	  color("gray") translate([0,120,0]) cube([100,12,spessore],center=true);  // laterale
	  color("gray") translate([0,-120,0]) cube([100,12,spessore],center=true); // laterale
  }	
}


// plinto verticale centrale
	color("gray", alpha) {
// PLINTO_2A
//!projection() rotate([0,-90,0])
	difference() {
    translate([80-spessore*1.5,0,20]) cube([spessore,40,400],center=true); // plinto verticale 2
		translate([40,0,210]) cube([144,20,20],center=true);  // foro per trave orizzontale in alto
	translate([distanza/2 - 30,0,130]) cube([spessore,240,spessore],center=true);   // scanalatura tramezzo anteriore
		translate([-80,0,0])	rotate([0,90,0]) cylinder(h=200,r=raggioforo, $fn=32); // foro leonardo
	  translate([50,0,48])	rotate([0,90,0]) cylinder(h=80,r=raggioforo, $fn=32);  // foro secondi
	  translate([50,0,-80])	rotate([0,90,0]) cylinder(h=160,r=raggioforo, $fn=32);  // foro carica
	}
// PLINTO_2B
//!projection() rotate([0,-90,0])
	difference() {
    translate([80-spessore*2.5,0,20]) cube([spessore,40,400],center=true); // plinto verticale 2
		translate([40,0,210]) cube([144,20,20],center=true);  // foro per trave orizzontale in alto
		translate([distanza/2 + 40,0,130]) cube([spessore,240,spessore],center=true);   // scanalatura tramezzo posteriore
		translate([-80,0,0])	rotate([0,90,0]) cylinder(h=200,r=raggioforo, $fn=32); // foro leonardo
	  translate([50,0,48])	rotate([0,90,0]) cylinder(h=80,r=raggioasse*1.2, $fn=32);  // foro asse secondi (largo)
	  translate([50,0,-80])	rotate([0,90,0]) cylinder(h=160,r=raggioasse*1.2, $fn=32);  // foro asse carica (largo)
	}	
}


// plinto verticale anteriore
   color("gray", alpha) {
// PLINTO_3A (strato anteriore)
//!projection() rotate([0,-90,0])
	difference() {
        union() {
    translate([120-spessore*1.5,0,20]) cube([spessore,40,400],center=true); // plinto verticale 3
            }
		translate([40,0,210]) cube([144,20,20],center=true);  // foro per trave orizzontale in alto
		translate([-40,0,0])	rotate([0,90,0]) cylinder(h=200,r=raggioasse*1.2, $fn=32); // foro asse leonardo (largo)
		translate([50,0,48])	rotate([0,90,0]) cylinder(h=80,r=raggioasse*1.2, $fn=32); // foro asse secondi (largo)
		translate([50,0,-80])	rotate([0,90,0]) cylinder(h=160,r=raggioforo, $fn=32); // foro carica

	}
	
// PLINTO_3B (strato posteriore)
//!projection() rotate([0,-90,0])
	difference() {
        union() {
    translate([120-spessore*2.5,0,20]) cube([spessore,40,400],center=true); // plinto verticale 3
            }
		translate([40,0,210]) cube([144,20,20],center=true);  // foro per trave orizzontale in alto
		translate([-40,0,0])	rotate([0,90,0]) cylinder(h=200,r=raggioforo, $fn=32); // foro leonardo
		translate([50,0,48])	rotate([0,90,0]) cylinder(h=80,r=raggioforo, $fn=32); // foro secondi
		translate([50,0,-80])	rotate([0,90,0]) cylinder(h=160,r=raggioforo, $fn=32); // foro carica

	}
	
}


// sostegno ruota di carica (plinto verticale 4)
// PLINTO_4A (posteriore)
//!projection() rotate([0,-90,0])
	color("gray", alpha) difference() {
    translate([200,0,-120]) cube([spessore,40,120],center=true); // plinto verticale  
		translate([180,0,-80])	rotate([0,90,0]) cylinder(h=40,r=raggioforo, $fn=32); // foro cuscinetto
	}
// PLINTO_4B (anteriore)
//!projection() rotate([0,-90,0])
	color("grey", alpha) difference() {
    translate([210,0,-120]) cube([spessore,40,120],center=true); // plinto verticale  
		translate([180,0,-80])	rotate([0,90,0]) cylinder(h=40,r=raggioasse*1.2, $fn=32); // foro asse (largo)
	}
    
    
// BASE_A
//!projection() translate([0,0,85]) 
	color("gray", alpha) difference() {
	translate([90,0,-174]) cube([280,160,spessore],center=true); // piastra orizzontale (base di appoggio)
	translate([-spessore*2,0,120]) cube([spessore*2,40,600],center=true); //foro del plinto verticale 1
	translate([60,0,70]) cube([spessore*2,40,500],center=true); //foro del plinto verticale 2
	translate([100,0,70]) cube([spessore*2,40,500],center=true); //foro del plinto verticale  3
	translate([205,0,-120]) cube([spessore*2,40,120],center=true); // foro del plinto verticale 4
    translate([156,26,-160]) scale([1.2,0.3,1]) cylinder(h=120,r=30,center=true); // foro per il cavo del peso
}

// BASE_B
//!projection() translate([0,0,85]) 
	color("gray", alpha) difference() {
	translate([90,0,-174-spessore]) union() {
        cube([280,160,spessore],center=true); // piastra orizzontale (base di appoggio)
        translate([-80,-90,0]) cylinder(r=20,h=spessore,center=true); // incastri tondi "maschi" per moduli aggiuntivi
        translate([80,-90,0]) cylinder(r=20,h=spessore,center=true);
    } 
	#translate([-spessore*2,0,-160]) cylinder(r=1,h=10*spessore,center=true); //foro vite per plinto verticale 1
	#translate([60,0,-160]) cylinder(r=1,h=10*spessore,center=true); //foro vite per plinto verticale 2
	#translate([100,0,-160]) cylinder(r=1,h=10*spessore,center=true); //foro vite per plinto verticale  3
	#translate([205,0,-160]) cylinder(r=1,h=10*spessore,center=true); // foro vite per plinto verticale 4
    translate([156,26,-160]) scale([1.2,0.3,1]) cylinder(h=120,r=30,center=true); // foro per il cavo del peso
}



// fine del blocco base "orologio di Leonardo"


// inizio del blocco aggiuntivo che esegue una demoltiplica 8:1 per la lancetta "dei minuti"
    
if(false) {
    
/* 
// BASE2
//!projection(cut=true) 
	color("brown") difference() {
	translate([45,-80,-87]) cube([140,80,10],center=true); // piastra orizzontale (base di appoggio)
	translate([30,-80,35]) cube([spessore*2,20,250],center=true); //foro del plinto verticale 5
	translate([50,-80,35]) cube([spessore*2,20,250],center=true); //foro del plinto verticale  6
	
}

// plinto verticale centrale minuti (2 strati uguali)
color("brown") {
// PLINTO_5A (uguale al 5B)
//!projection() rotate([0,-90,0])
  union() {
    // vertical part
	difference() {
    translate([40-spessore*1.5,-80,-20]) cube([spessore,20,140],center=true); // plinto verticale
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
	  translate([25,-80,24])	rotate([0,90,0]) cylinder(h=40,r=raggioforo, $fn=32);  // foro alto
	   
	}
    // horizontal part
    difference() {
    translate([40-spessore*1.5,-40,24]) cube([spessore,60,20],center=true); // plinto orizzontale
		translate([-40,-32,24])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro 
	}
    
    // diagonal part
    difference() {
      union() {
        translate([40-spessore*2.5,-50.1,-9.7]) rotate([-75,0,0]) cube([spessore,20,52.8],center=true);
        translate([40-spessore*2.5,-32,10]) cube([spessore,20,45],center=true);
      }
        translate([-40,-32,24])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32);  // foro alto
      translate([-40,-40,-6.75])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32);  // foro medio
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
    }
    
  }
// PLINTO_5B (uguale al 5A)
//!projection() rotate([0,-90,0])
  union() {
	difference() {
    translate([40-spessore*2.5,-80,-20]) cube([spessore,20,140],center=true); // plinto verticale 2
		translate([20,-80,155]) cube([72,10,10],center=true);  // foro per trave orizzontale in alto
		translate([distanza/2 + 20,-80,65]) cube([6,120,5],center=true);   // scanalatura tramezzo posteriore
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
	  translate([25,-80,24])	rotate([0,90,0]) cylinder(h=40,r=raggioforo, $fn=32);  // foro alto
	  
	}	
  // horizontal part
    difference() {
    translate([40-spessore*2.5,-40,24]) cube([spessore,60,20],center=true); // plinto orizzontale
		translate([-40,-32,24])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro 
	}
    
    // diagonal part
    difference() {
      union() {
        translate([40-spessore*1.5,-50.1,-9.7]) rotate([-75,0,0]) cube([spessore,20,52.8],center=true);
        translate([40-spessore*1.5,-32,10]) cube([spessore,20,45],center=true);
      }
        translate([-40,-32,24])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32);  // foro alto
      translate([-40,-40,-6.75])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32);  // foro medio
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
    }
  }
}

// ingranaggio di collegamento, che si aggancia sul modulo dei secondi Z=20
// GEAR_Z20_COLLEGAMENTO
//!projection() rotate([0,-90,0])
color("green") difference() {
	translate([40,-32,24]) rotate([$t*360*2+9,0,0]) rotate([0,90,0]) gear(mm_per_tooth=5, number_of_teeth=20, thickness=spessore, hole_diameter=4);
	translate([40-spessore/2,-32,24])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);  // foro asse
}

// suo asse di rotazione
translate([25,-32,24])	rotate([0,90,0]) cylinder(h=30,r=raggioasse, $fn=32);

// GEAR_Z8_RIDUZ
//!projection() rotate([0,-90,0])
color("pink") difference() {
    translate([45,-32,24]) rotate([$t*360*2+9,0,0]) rotate([0,90,0]) gear(mm_per_tooth=5, number_of_teeth=8, thickness=spessore, hole_diameter=4);
    translate([45-spessore/2,-32,24])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);  // foro asse
}

// GEAR_Z32_RIDUZ
//!projection() rotate([0,-90,0])
color("pink") difference() {
    translate([45,-40,-6.75]) rotate([-$t*360/2+7.6,0,0]) rotate([0,90,0]) gear(mm_per_tooth=5, number_of_teeth=32, thickness=spessore, hole_diameter=4);
    translate([45-spessore/2,-40,-6.75])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);  // foro asse
}

// GEAR_Z10_RIDUZ
//!projection() rotate([0,-90,0])
color("blue") difference() {
    translate([40,-40,-6.75]) rotate([-$t*360/2+7.6,0,0]) rotate([0,90,0]) gear(mm_per_tooth=5, number_of_teeth=10, thickness=spessore, hole_diameter=4);
    translate([40-spessore/2,-40,-6.75])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);  // foro asse
}

// suo asse di rotazione
translate([25,-40,-6.75])	rotate([0,90,0]) cylinder(h=30,r=raggioasse, $fn=32);


// GEAR_Z30_RIDUZ
//!projection() rotate([0,-90,0])
color("red") difference() {
    translate([40,-71,-15]) rotate([$t*360/6+11,0,0]) rotate([0,90,0]) gear(mm_per_tooth=5, number_of_teeth=30, thickness=spessore, hole_diameter=4);
    translate([40-spessore/2,-71,-15])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);  // foro asse
}

// suo asse di rotazione
translate([25,-71,-15])	rotate([0,90,0]) cylinder(h=30,r=raggioasse, $fn=32);

// plinto verticale anteriore minuti (2 strati differenti)
color("brown") {
// PLINTO_6A
//!projection() rotate([0,-90,0])
  union() {
    // vertical part
	difference() {
    translate([60-spessore*1.5,-80,-20]) cube([spessore,20,140],center=true); // plinto verticale
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
	  translate([25,-80,24])	rotate([0,90,0]) cylinder(h=40,r=raggioforo, $fn=32);  // foro alto
	   
	}
    // horizontal part
    difference() {
      translate([60-spessore*1.5,-40,24]) cube([spessore,60,20],center=true); // plinto orizzontale
      translate([-40,-32,24])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro 
	}
    
    // diagonal part
    difference() {
      union() {
        translate([60-spessore*1.5,-50.1,-9.7]) rotate([-75,0,0]) cube([spessore,20,52.8],center=true);
        translate([60-spessore*1.5,-32,10]) cube([spessore,20,45],center=true);
      }
        translate([-40,-32,24])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32);  // foro alto
      translate([-40,-40,-6.75])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32);  // foro medio
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
    }
  }
// PLINTO_6B
//!projection() rotate([0,-90,0])
	difference() {
    translate([60-spessore*2.5,-80,-20]) cube([spessore,20,140],center=true); // plinto verticale 2
		translate([-40,-71,-15])	rotate([0,90,0]) cylinder(h=100,r=raggioforo, $fn=32); // foro basso
	  translate([25,-80,24])	rotate([0,90,0]) cylinder(h=40,r=raggioforo, $fn=32);  // foro alto
	  
	}	
}

// ingranaggio per la ruota dei minuti Z=20
// GEAR_Z20_MINUTI
//!projection() rotate([0,-90,0])
color("green") difference() {
	translate([40,-80,24]) rotate([-$t*360/4-2,0,0]) rotate([0,90,0]) gear(mm_per_tooth=5, number_of_teeth=20, thickness=spessore, hole_diameter=4);
	translate([40-spessore/2,-80,24])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);  // foro asse
}
// suo asse di rotazione
translate([25,-80,24])	rotate([0,90,0]) cylinder(h=40,r=raggioasse, $fn=32);

// lancetta dei minuti
// MINUTI
//!projection() rotate([0,-90,0])
translate([56,-80,24]) rotate([-$t*360/4,0,0]) rotate([0,90,0]) {
	difference() {
	union() {
		cylinder(h=spessore,r=10, $fn=32);  // ruota tonda
	  translate([0,-1.5,0]) color("red") cube([30,3,spessore]);  // ago dei secondi
	}
	cylinder(h=spessore,r=raggioasse, $fn=32);  // foro asse
}
}

*/

} // end if
// fine del blocco che esegue una demoltiplica 8:1 per la lancetta "dei minuti"


// definizione delle funzioni e moduli

module leonardogear(radius=100,thickness=10,pins=12,pinradius=8,pinlenght=14,centralradius=raggioasse,pinoffset=0) {
	// external rim
	difference() {
	cylinder(h=thickness,r=radius,center=true, $fn=64);
	cylinder(h=thickness+2,r=radius-2*spessore,center=true, $fn=64);
	}
	
	// radial segments
	for (i = [1:3:pins]) {
			rotate([0,0,i*360/(pins)+pinoffset*(180/pins)]) {
				translate([radius/2,0,0]) rotate([0,90,0]) {
					cube([spessore,12,radius-centralradius],center=true);
				}
			}
		}
	
	//internal rim
	difference() {
	rotate([0,0,360/(pins)+pinoffset*(180/pins)]) cylinder(h=thickness,r=centralradius+4*spessore,center=true, $fn=5);
	cylinder(h=thickness+2,r=centralradius,center=true, $fn=64);
	}
	
		for (i = [1:pins]) {
			rotate([0,0,i*360/pins]) {
				translate([radius+pinlenght/2-pinradius,0,0]) rotate([0,90,0]) union(){
					cube([spessore,pinradius*2,pinlenght],center=true);
					translate([-spessore/2,0,6]) rotate([0,90,0]) cylinder(h=spessore,r=pinradius, $fn=32);
				}
			}
		}
}

//TEST leonardogear:
//!leonardogear(radius=raggio,thickness=spessore,pins=denti,pinradius=raggiopiolo,pinlenght=piolo,pinoffset=0,$fn=64);


module paletta() {
	difference(){
		union() {
	   cylinder(h=spessore, r=10, center=true);
	    for (i = [-45,45,180]) {
	     rotate([0,0,i]) {
				translate([15,0,0]) rotate([0,90,0]) union(){
					cube([spessore,8,12],center=true);
					translate([-spessore/2,0,6]) rotate([0,90,0]) cylinder(h=spessore,r=4, $fn=32);
				}
			}
	   }
    }
		// foro per asse
		cylinder(h=20, r=4, center=true);
  }
}

//TEST paletta:
//!paletta();

module nottolino(notlung=20,notforo=0.55,notthick=spessore) {
    
   
    difference() {
        union() {
            cylinder(r=notlung/4,h=notthick, center= true);
            translate([-notlung*0.8,-notlung/4,-notthick/2]) cube([notlung*0.8,notlung/2,notthick]);
    
            translate([-notlung*0.8,0,0]) cylinder(r=notlung/4,h=notthick, center= true);
    
            translate([-notlung*0.78,-notlung*0.46,-notthick/2]) scale([0.8,1,1]) rotate([0,0,40]) cube([notlung*0.5,notlung*0.5,notthick]);
        }
        
        cylinder(r=notforo,h=notthick+0.2, center= true);
        
    }
    
    
}

//TEST nottolino:
//!nottolino();

module cuscinetto(IDcusc=raggioasse, ODcusc=raggioforo, hcusc=8) {
    
    color("yellow") difference() {
    cylinder(r=ODcusc,h=hcusc,center=true);
    cylinder(r=IDcusc,h=hcusc+0.2,center=true);
    }
}

//TEST cuscinetto:
//!cuscinetto();